nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

BootCfg

Struct BootCfg 

#[repr(transparent)]
pub struct BootCfg(pub u32);
no description available

Tuple Fields

0: u32

Implementations

Source

impl BootCfg

pub const fn default_isp_mode(&self) -> DefaultIspMode

Default ISP mode:

pub const fn set_default_isp_mode(&mut self, val: DefaultIspMode)

Default ISP mode:

pub const fn boot_speed(&self) -> BootSpeed

Core clock:

pub const fn set_boot_speed(&mut self, val: BootSpeed)

Core clock:

pub const fn boot_failure_pin(&self) -> u8

GPIO port and pin number to use for indicating failure reason. The toggle rate of the pin is used to decode the error type. [2:0] - Defines GPIO port [7:3] - Defines GPIO pin

pub const fn set_boot_failure_pin(&mut self, val: u8)

GPIO port and pin number to use for indicating failure reason. The toggle rate of the pin is used to decode the error type. [2:0] - Defines GPIO port [7:3] - Defines GPIO pin