#[repr(transparent)]pub struct BootCfg(pub u32);Expand description
no description available
Tuple Fields
0: u32Implementations
Sourceimpl BootCfg
impl BootCfg
Sourcepub const fn default_isp_mode(&self) -> DefaultIspMode
pub const fn default_isp_mode(&self) -> DefaultIspMode
Default ISP mode:
Sourcepub const fn set_default_isp_mode(&mut self, val: DefaultIspMode)
pub const fn set_default_isp_mode(&mut self, val: DefaultIspMode)
Default ISP mode:
Sourcepub const fn boot_speed(&self) -> BootSpeed
pub const fn boot_speed(&self) -> BootSpeed
Core clock:
Sourcepub const fn set_boot_speed(&mut self, val: BootSpeed)
pub const fn set_boot_speed(&mut self, val: BootSpeed)
Core clock:
Sourcepub const fn boot_failure_pin(&self) -> u8
pub const fn boot_failure_pin(&self) -> u8
GPIO port and pin number to use for indicating failure reason. The toggle rate of the pin is used to decode the error type. [2:0] - Defines GPIO port [7:3] - Defines GPIO pin
Sourcepub const fn set_boot_failure_pin(&mut self, val: u8)
pub const fn set_boot_failure_pin(&mut self, val: u8)
GPIO port and pin number to use for indicating failure reason. The toggle rate of the pin is used to decode the error type. [2:0] - Defines GPIO port [7:3] - Defines GPIO pin